# Kassandra

Description.

I'm open to all feedback, commentary, and suggestions as long as they are constructive and polite.

### Authors

**James Montgomery** - *Initial work* - [jamesmontgomery.us](http://jamesmontgomery.us)

### License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Installing


### Basic Examples

Regression Examples
* [Multi Layer Perceptron](https://github.com/James-Montgomery/kassandra/tree/master/docs/examples/Regression/Multi_Layer_Perceptron.ipynb)
* [Gaussian Process](https://github.com/James-Montgomery/kassandra/tree/master/docs/examples/Regression/Gaussian_Process.ipynb)
* [Bayesian Neural Network with MCDropout](https://github.com/James-Montgomery/kassandra/tree/master/docs/examples/Regression/Bayesian_Network_Dropout.ipynb)
* [Bayesian Neural Network with Variational Inference](https://github.com/James-Montgomery/kassandra/tree/master/docs/examples/Regression/Bayesian_Network_Variational_Inference.ipynb)

Classification Examples (TBD)
* Multi Layer Perceptron
* Gaussian Process
* Bayesian Neural Network with MCDropout
* Bayesian Neural Network with Variational Inference

## Testing

Testing is an important part of creating maintainable, production grade code.

### Running the unit tests


### Running the style tests


## Acknowledgments
